@@ -21,11 +21,6 @@ renv_methods_map <- function() {
     renv_file_broken = c(
       unix  = "renv_file_broken_unix",
       win32 = "renv_file_broken_win32"
-    ),
-
-    renv_paths_sandbox = c(
-      unix  = "renv_paths_sandbox_unix",
-      win32 = "renv_paths_sandbox_win32"
     )
 
   )
@@ -40,7 +35,7 @@ renv_methods_init <- function() {
   # determine appropriate lookup key for finding alternative
   key <- if (renv_platform_windows()) "win32" else "unix"
   alts <- map(methods, `[[`, key)
-
+  
   # update methods in namespace
   envir <- renv_envir_self()
   enumerate(alts, function(name, alt) {
