@@ -750,7 +750,7 @@ renv_snapshot_description_impl_v1 <- function(dcf, path = NULL) {
   # if this is a standard remote for a bioconductor package,
   # remove the other remote fields
   bioc <-
-    !is.null(dcf[["biocViews"]]) &&
+    nzchar(dcf[["biocViews"]] %||% "") &&
     identical(dcf[["RemoteType"]], "standard")
 
   if (bioc) {
@@ -822,7 +822,7 @@ renv_snapshot_description_impl_v2 <- function(dcf, path) {
   # if this is a standard remote for a bioconductor package,
   # remove the other remote fields
   bioc <-
-    !is.null(dcf[["biocViews"]]) &&
+    nzchar(dcf[["biocViews"]] %||% "") &&
     identical(dcf[["RemoteType"]], "standard")
 
   if (bioc) {
@@ -878,8 +878,12 @@ renv_snapshot_description_source_custom <- function(dcf) {
     return(NULL)
 
   # if this package appears to be installed from Bioconductor, skip
-  biocviews <- dcf[["biocViews"]]
-  if (!is.null(biocviews))
+  if (nzchar(dcf[["biocViews"]] %||% ""))
+    return(NULL)
+
+  # if the declared repository appears to be a CRAN mirror, skip it
+  mirrors <- renv_cran_mirrors()
+  if (any(renv_repos_matches(remoterepos, mirrors)))
     return(NULL)
 
   # if this package appears to have been installed from a
@@ -889,11 +893,17 @@ renv_snapshot_description_source_custom <- function(dcf) {
   if (!is.null(repository) && repository %in% names(repos))
     return(NULL)
 
-  # check whether this repository is already in use;
-  # if so, we can skip declaring it
+  # check whether the declared repository matches one of the
+  # repositories that are currently in use; if so, skip it
+  #
+  # we explicitly ignore 'CRAN' as a repository name here, since older
+  # versions of renv may have erroneously marked packages installed from
+  # other package repositories as 'CRAN'
+  #
+  # https://github.com/rstudio/renv/issues/2104
   name <- dcf[["RemoteReposName"]]
-  declared <- if (is.null(name))
-    remoterepos %in% repos
+  declared <- if (is.null(name) || identical(name, "CRAN"))
+    renv_repos_matches(remoterepos, repos)
   else
     name %in% names(repos)
 
@@ -920,7 +930,7 @@ renv_snapshot_description_source <- function(dcf) {
 
   # packages from Bioconductor are normally tagged with a 'biocViews' entry;
   # use that to infer a Bioconductor source
-  if (!is.null(dcf[["biocViews"]]))
+  if (nzchar(dcf[["biocViews"]] %||% ""))
     return(list(Source = "Bioconductor"))
 
   # check for a declared repository
