@@ -1,6 +1,4 @@
 
-context("Files")
-
 test_that("directories can be copied", {
 
   source <- renv_scope_tempfile("renv-source-")
@@ -59,7 +57,7 @@ test_that("scoped backups are cleared as necessary", {
 
   local({
     callback <- renv_file_backup(target)
-    on.exit(callback(), add = TRUE)
+    defer(callback())
     expect_true(!file.exists(target))
   })
 
@@ -68,7 +66,7 @@ test_that("scoped backups are cleared as necessary", {
 
   local({
     callback <- renv_file_backup(target)
-    on.exit(callback(), add = TRUE)
+    defer(callback())
     writeLines("mutate", target)
   })
 
@@ -100,7 +98,7 @@ test_that("renv tempfiles are deleted at end of scope", {
 
 test_that("renv_file_find finds parent files", {
 
-  base <- tempfile("renv-files-")
+  base <- renv_scope_tempfile("renv-files-")
   rest <- c("alpha/beta/gamma")
   tip <- file.path(base, rest)
   ensure_directory(tip)
@@ -165,7 +163,7 @@ test_that("renv can list files not representable in the native encoding", {
   evil <- "\u9b3c"
 
   file.create(evil)
-  on.exit(unlink(evil), add = TRUE)
+  defer(unlink(evil))
 
   files <- renv_file_list(getwd(), full.names = FALSE)
   expect_true(evil %in% files)
@@ -174,11 +172,11 @@ test_that("renv can list files not representable in the native encoding", {
 
 test_that("renv can detect broken junctions / symlinks", {
 
-  owd <- setwd(tempdir())
-  on.exit(setwd(owd), add = TRUE)
+  renv_scope_tempdir()
 
   if (renv_platform_windows()) {
 
+    file.create("file")
     dir.create("dir")
     dir.create("nowhere")
     Sys.junction("dir", "junction")
@@ -202,3 +200,23 @@ test_that("renv can detect broken junctions / symlinks", {
 
 })
 
+test_that("renv can detect junction points", {
+  skip_on_cran()
+  skip_if(!renv_platform_windows())
+
+  renv_scope_tempdir()
+  dir.create("source")
+  defer(unlink("source", recursive = TRUE))
+
+  # create some files -- should give the directory a size,
+  # but this seems unreliable?
+  files <- sprintf("source/%05i.txt", 1:100)
+  file.create(files)
+
+  # create a junction point
+  Sys.junction("source", "junction")
+  defer(unlink("junction", recursive = TRUE))
+
+  # check that they're the same
+  expect_true(renv_file_same("source", "junction"))
+})
